@@ -35,6 +35,7 @@ warnings.filterwarnings("ignore", "Accessed deprecated property",
                         DeprecationWarning)
 
 import distro_info
+import fnmatch
 import os
 import subprocess
 import sys
@@ -87,6 +88,7 @@ class UpdateManager(Gtk.Window):
         self.update_list = None
         self.meta_release = None
         self.hwe_replacement_packages = None
+        self.oem_metapackages = set()
         self.duplicate_packages = []
         self.arch = get_arch()
 
@@ -222,7 +224,7 @@ class UpdateManager(Gtk.Window):
         self._start_pane(update_backend)
 
     def start_install(self, hwe_upgrade=False):
-        install_backend = get_backend(self, InstallBackend.ACTION_INSTALL)
+        install_backend = get_backend(self, InstallBackend.ACTION_PRE_INSTALL)
         if hwe_upgrade:
             for pkgname in self.hwe_replacement_packages:
                 try:
@@ -244,6 +246,27 @@ class UpdateManager(Gtk.Window):
                                          cancelled_update, error_occurred)
         self._start_pane(pane)
 
+    def _check_oem_metapackages(self):
+        di = distro_info.UbuntuDistroInfo()
+        codename = get_dist()
+        lts = di.is_lts(codename)
+        if not lts:
+            return None
+        OEM_PATH = os.path.join(GLib.get_user_runtime_dir(),
+                                "ubuntu-drivers-oem.package-list")
+        if not os.path.exists(OEM_PATH):
+            return None
+
+        # Packages that aren't installed but apply to this system
+        with open(OEM_PATH, 'r') as f:
+            self.oem_metapackages |= set(f.read().splitlines())
+
+        # Packages that are already installed
+        for pkg in self.cache:
+            if fnmatch.fnmatch(pkg.name, 'oem-*-meta') \
+               and pkg.installed:
+                self.oem_metapackages.add(pkg)
+
     def _make_available_pane(self, install_count, need_reboot=False,
                              cancelled_update=False, error_occurred=False):
         self._check_hwe_support_status()
@@ -397,6 +420,15 @@ class UpdateManager(Gtk.Window):
                 Gtk.main_iteration()
         iterate()
 
+        self._check_oem_metapackages()
+
+        for pkgname in self.oem_metapackages:
+            try:
+                if not self.cache[pkgname].is_installed:
+                    self.cache[pkgname].mark_install()
+            except SystemError:
+                pass
+
         self.update_list = UpdateList(self)
         try:
             self.update_list.update(self.cache, eventloop_callback=iterate,
